aboutsummaryrefslogtreecommitdiff
path: root/internal/cmd
diff options
context:
space:
mode:
authorShulhan <ms@kilabit.info>2022-08-25 11:04:51 +0700
committerShulhan <ms@kilabit.info>2022-08-25 11:44:39 +0700
commit79821d0ee69809fe387293bbe52dcdb0075196d7 (patch)
tree36316280f24326237f635f7a2d77cbf94b8f3a3b /internal/cmd
parentce1f8a856ee26c582aab9dce58b87d822c581d51 (diff)
downloadgorankusu-79821d0ee69809fe387293bbe52dcdb0075196d7.tar.xz
all: group all documentations under directory _doc
The _doc directory provides an entry point for all documentation. While at it we reformat the README to use AsciiDoc markup.
Diffstat (limited to 'internal/cmd')
-rw-r--r--internal/cmd/trunks/main.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/internal/cmd/trunks/main.go b/internal/cmd/trunks/main.go
index 1367214..5680811 100644
--- a/internal/cmd/trunks/main.go
+++ b/internal/cmd/trunks/main.go
@@ -135,7 +135,7 @@ func workerBuild(oneTime bool) {
`/wui/index\.html$`,
`/wui\.bak`,
`/wui\.local`,
- `docs`,
+ `doc`,
},
},
}
@@ -190,14 +190,14 @@ func workerBuild(oneTime bool) {
}
// workerDocs a goroutine that watch any changes to .adoc files inside
// "_www/docs" directory and convert them into HTML files.
func workerDocs() {
logp := "workerDocs"
mlog.Outf(`%s: started ...`, logp)
opts := &ciigo.ConvertOptions{
- Root: "_www/docs",
+ Root: "_doc",
}
err := ciigo.Watch(opts)
if err != nil {
@@ -190,14 +190,14 @@ func workerBuild(oneTime bool) {
}
// workerDocs a goroutine that watch any changes to .adoc files inside
-// "_www/docs" directory and convert them into HTML files.
+// "_doc" directory and convert them into HTML files.
func workerDocs() {
logp := "workerDocs"